==> node-fetch-sessions-1.0.2.tgz: package/README.md <==
![LambdaTest Logo](https://www.lambdatest.com/resources/images/logos/logo.svg)

# Node fetch sessions

[![npm version](https://img.shields.io/npm/v/@lambdatest/node-fetch-sessions.svg?style=flat)](https://www.npmjs.com/package/@lambdatest/node-fetch-sessions)

A command-line interface(CLI) to fetch [LambdaTest](https://www.lambdatest.com) automation session details through [@lambdatest/node-rest-client](https://www.npmjs.com/package/@lambdatest/node-rest-client).

## Installation

```
npm i -g  @lambdatest/node-fetch-sessions
```

## Example

```sh

// The username for the LambdaTest account
export LT_USERNAME=abc

// The accessKey for the LambdaTest account
export LT_ACCESS_KEY=def

// The build name whose test session information is to be fetched
export LT_BUILD=Demo

fetch-Lt-sessions
```

## **License**

Node fetch sessions is available under the [Apache License 2.0](https://github.com/LambdaTest/node-fetch-session/blob/main/LICENSE). Use it wisely.

## About LambdaTest

[LambdaTest](https://www.lambdatest.com/?utm_source=github&utm_medium=repo&utm_campaign=node-fetch-session) is a leading test execution and orchestration platform that is fast, reliable, scalable, and secure. It allows users to run both manual and automated testing of web and mobile apps across 3000+ different browsers, operating systems, and real device combinations. Using LambdaTest, businesses can ensure quicker developer feedback and hence achieve faster go to market. Over 500 enterprises and 1 Million + users across 130+ countries rely on LambdaTest for their testing needs.

### Features

-   Run Selenium, Cypress, Puppeteer, Playwright, and Appium automation tests across 3000+ real desktop and mobile environments.
-   Real-time cross browser testing on 3000+ environments.
-   Test on Real device cloud
-   Blazing fast test automation with HyperExecute
-   Accelerate testing, shorten job times and get faster feedback on code changes with Test At Scale.
-   Smart Visual Regression Testing on cloud
-   120+ third-party integrations with your favorite tool for CI/CD, Project Management, Codeless Automation, and more.
-   Automated Screenshot testing across multiple browsers in a single click.
-   Local testing of web and mobile apps.
-   Online Accessibility Testing across 3000+ desktop and mobile browsers, browser versions, and operating systems.
-   Geolocation testing of web and mobile apps across 53+ countries.
-   LT Browser - for responsive testing across 50+ pre-installed mobile, tablets, desktop, and laptop viewports

==> node-fetch-sessions-1.0.4.tgz: package/README.md <==
![LambdaTest Logo](https://www.lambdatest.com/resources/images/logos/logo.svg)

# Node fetch sessions

[![npm version](https://img.shields.io/npm/v/@lambdatest/node-fetch-sessions.svg?style=flat)](https://www.npmjs.com/package/@lambdatest/node-fetch-sessions)

A command-line interface(CLI) to fetch [LambdaTest](https://www.lambdatest.com) automation session details through [@lambdatest/node-rest-client](https://www.npmjs.com/package/@lambdatest/node-rest-client).

## Installation

```
npm i -g  @lambdatest/node-fetch-sessions
```

## Example

```sh

// The username for the LambdaTest account
export LT_USERNAME=abc

// The accessKey for the LambdaTest account
export LT_ACCESS_KEY=def

// The build name whose test session information is to be fetched
export LT_BUILD_NAME=Demo

fetch-Lt-sessions
```

## **License**

Node fetch sessions is available under the [Apache License 2.0](https://github.com/LambdaTest/node-fetch-session/blob/main/LICENSE). Use it wisely.

## About LambdaTest

[LambdaTest](https://www.lambdatest.com/?utm_source=github&utm_medium=repo&utm_campaign=node-fetch-session) is a leading test execution and orchestration platform that is fast, reliable, scalable, and secure. It allows users to run both manual and automated testing of web and mobile apps across 3000+ different browsers, operating systems, and real device combinations. Using LambdaTest, businesses can ensure quicker developer feedback and hence achieve faster go to market. Over 500 enterprises and 1 Million + users across 130+ countries rely on LambdaTest for their testing needs.

### Features

-   Run Selenium, Cypress, Puppeteer, Playwright, and Appium automation tests across 3000+ real desktop and mobile environments.
-   Real-time cross browser testing on 3000+ environments.
-   Test on Real device cloud
-   Blazing fast test automation with HyperExecute
-   Accelerate testing, shorten job times and get faster feedback on code changes with Test At Scale.
-   Smart Visual Regression Testing on cloud
-   120+ third-party integrations with your favorite tool for CI/CD, Project Management, Codeless Automation, and more.
-   Automated Screenshot testing across multiple browsers in a single click.
-   Local testing of web and mobile apps.
-   Online Accessibility Testing across 3000+ desktop and mobile browsers, browser versions, and operating systems.
-   Geolocation testing of web and mobile apps across 53+ countries.
-   LT Browser - for responsive testing across 50+ pre-installed mobile, tablets, desktop, and laptop viewports
